==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class AppsV1beta1DeploymentStatusFluentImpl<A extends AppsV1beta1DeploymentStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements AppsV1beta1DeploymentStatusFluent<A>{

    private Integer availableReplicas;
    private Integer collisionCount;
    private List<AppsV1beta1DeploymentConditionBuilder> conditions;
    private Long observedGeneration;
    private Integer readyReplicas;
    private Integer replicas;
    private Integer unavailableReplicas;
    private Integer updatedReplicas;

    public AppsV1beta1DeploymentStatusFluentImpl(){
    }
    public AppsV1beta1DeploymentStatusFluentImpl(AppsV1beta1DeploymentStatus instance){
            this.withAvailableReplicas(instance.getAvailableReplicas());

            this.withCollisionCount(instance.getCollisionCount());

            this.withConditions(instance.getConditions());

            this.withObservedGeneration(instance.getObservedGeneration());

            this.withReadyReplicas(instance.getReadyReplicas());

            this.withReplicas(instance.getReplicas());

            this.withUnavailableReplicas(instance.getUnavailableReplicas());

            this.withUpdatedReplicas(instance.getUpdatedReplicas());

    }

    public Integer getAvailableReplicas(){
            return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas){
            this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas(){
            return this.availableReplicas != null;
    }

    public A withNewAvailableReplicas(int arg1){
            return (A)withAvailableReplicas(new Integer(arg1));
    }

    public A withNewAvailableReplicas(String arg1){
            return (A)withAvailableReplicas(new Integer(arg1));
    }

    public Integer getCollisionCount(){
            return this.collisionCount;
    }

    public A withCollisionCount(Integer collisionCount){
            this.collisionCount=collisionCount; return (A) this;
    }

    public Boolean hasCollisionCount(){
            return this.collisionCount != null;
    }

    public A withNewCollisionCount(int arg1){
            return (A)withCollisionCount(new Integer(arg1));
    }

    public A withNewCollisionCount(String arg1){
            return (A)withCollisionCount(new Integer(arg1));
    }

    public A addToConditions(int index,AppsV1beta1DeploymentCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,AppsV1beta1DeploymentCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(AppsV1beta1DeploymentCondition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<AppsV1beta1DeploymentCondition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(AppsV1beta1DeploymentCondition... items){
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<AppsV1beta1DeploymentCondition> items){
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<AppsV1beta1DeploymentCondition> getConditions(){
            return build(conditions);
    }

    public List<AppsV1beta1DeploymentCondition> buildConditions(){
            return build(conditions);
    }

    public AppsV1beta1DeploymentCondition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public AppsV1beta1DeploymentCondition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public AppsV1beta1DeploymentCondition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public AppsV1beta1DeploymentCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentConditionBuilder> predicate){
            for (AppsV1beta1DeploymentConditionBuilder item: conditions) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withConditions(List<AppsV1beta1DeploymentCondition> conditions){
            if (this.conditions != null) { _visitables.removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>(); for (AppsV1beta1DeploymentCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
    }

    public A withConditions(AppsV1beta1DeploymentCondition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (AppsV1beta1DeploymentCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> addNewConditionLike(AppsV1beta1DeploymentCondition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> setNewConditionLike(int index,AppsV1beta1DeploymentCondition item){
            return new ConditionsNestedImpl(index, item);
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    public A withNewObservedGeneration(String arg1){
            return (A)withObservedGeneration(new Long(arg1));
    }

    public A withNewObservedGeneration(long arg1){
            return (A)withObservedGeneration(new Long(arg1));
    }

    public Integer getReadyReplicas(){
            return this.readyReplicas;
    }

    public A withReadyReplicas(Integer readyReplicas){
            this.readyReplicas=readyReplicas; return (A) this;
    }

    public Boolean hasReadyReplicas(){
            return this.readyReplicas != null;
    }

    public A withNewReadyReplicas(int arg1){
            return (A)withReadyReplicas(new Integer(arg1));
    }

    public A withNewReadyReplicas(String arg1){
            return (A)withReadyReplicas(new Integer(arg1));
    }

    public Integer getReplicas(){
            return this.replicas;
    }

    public A withReplicas(Integer replicas){
            this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas(){
            return this.replicas != null;
    }

    public A withNewReplicas(int arg1){
            return (A)withReplicas(new Integer(arg1));
    }

    public A withNewReplicas(String arg1){
            return (A)withReplicas(new Integer(arg1));
    }

    public Integer getUnavailableReplicas(){
            return this.unavailableReplicas;
    }

    public A withUnavailableReplicas(Integer unavailableReplicas){
            this.unavailableReplicas=unavailableReplicas; return (A) this;
    }

    public Boolean hasUnavailableReplicas(){
            return this.unavailableReplicas != null;
    }

    public A withNewUnavailableReplicas(int arg1){
            return (A)withUnavailableReplicas(new Integer(arg1));
    }

    public A withNewUnavailableReplicas(String arg1){
            return (A)withUnavailableReplicas(new Integer(arg1));
    }

    public Integer getUpdatedReplicas(){
            return this.updatedReplicas;
    }

    public A withUpdatedReplicas(Integer updatedReplicas){
            this.updatedReplicas=updatedReplicas; return (A) this;
    }

    public Boolean hasUpdatedReplicas(){
            return this.updatedReplicas != null;
    }

    public A withNewUpdatedReplicas(int arg1){
            return (A)withUpdatedReplicas(new Integer(arg1));
    }

    public A withNewUpdatedReplicas(String arg1){
            return (A)withUpdatedReplicas(new Integer(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AppsV1beta1DeploymentStatusFluentImpl that = (AppsV1beta1DeploymentStatusFluentImpl) o;
            if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
            if (collisionCount != null ? !collisionCount.equals(that.collisionCount) :that.collisionCount != null) return false;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (readyReplicas != null ? !readyReplicas.equals(that.readyReplicas) :that.readyReplicas != null) return false;
            if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
            if (unavailableReplicas != null ? !unavailableReplicas.equals(that.unavailableReplicas) :that.unavailableReplicas != null) return false;
            if (updatedReplicas != null ? !updatedReplicas.equals(that.updatedReplicas) :that.updatedReplicas != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends AppsV1beta1DeploymentConditionFluentImpl<AppsV1beta1DeploymentStatusFluent.ConditionsNested<N>> implements AppsV1beta1DeploymentStatusFluent.ConditionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final AppsV1beta1DeploymentConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,AppsV1beta1DeploymentCondition item){
                    this.index = index;
                    this.builder = new AppsV1beta1DeploymentConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new AppsV1beta1DeploymentConditionBuilder(this);
            }
    
    public N and(){
            return (N) AppsV1beta1DeploymentStatusFluentImpl.this.setToConditions(index, builder.build());
    }
    public N endCondition(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class AppsV1beta1DeploymentStatusFluentImpl<A extends AppsV1beta1DeploymentStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements AppsV1beta1DeploymentStatusFluent<A>{

    private Integer availableReplicas;
    private Integer collisionCount;
    private List<AppsV1beta1DeploymentConditionBuilder> conditions;
    private Long observedGeneration;
    private Integer readyReplicas;
    private Integer replicas;
    private Integer unavailableReplicas;
    private Integer updatedReplicas;

    public AppsV1beta1DeploymentStatusFluentImpl(){
    }
    public AppsV1beta1DeploymentStatusFluentImpl(AppsV1beta1DeploymentStatus instance){
            this.withAvailableReplicas(instance.getAvailableReplicas());

            this.withCollisionCount(instance.getCollisionCount());

            this.withConditions(instance.getConditions());

            this.withObservedGeneration(instance.getObservedGeneration());

            this.withReadyReplicas(instance.getReadyReplicas());

            this.withReplicas(instance.getReplicas());

            this.withUnavailableReplicas(instance.getUnavailableReplicas());

            this.withUpdatedReplicas(instance.getUpdatedReplicas());

    }

    public Integer getAvailableReplicas(){
            return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas){
            this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas(){
            return this.availableReplicas != null;
    }

    public Integer getCollisionCount(){
            return this.collisionCount;
    }

    public A withCollisionCount(Integer collisionCount){
            this.collisionCount=collisionCount; return (A) this;
    }

    public Boolean hasCollisionCount(){
            return this.collisionCount != null;
    }

    public A addToConditions(int index,AppsV1beta1DeploymentCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,AppsV1beta1DeploymentCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);
            if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(AppsV1beta1DeploymentCondition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<AppsV1beta1DeploymentCondition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>();}
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(AppsV1beta1DeploymentCondition... items){
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<AppsV1beta1DeploymentCondition> items){
            for (AppsV1beta1DeploymentCondition item : items) {AppsV1beta1DeploymentConditionBuilder builder = new AppsV1beta1DeploymentConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<AppsV1beta1DeploymentCondition> getConditions(){
            return build(conditions);
    }

    public List<AppsV1beta1DeploymentCondition> buildConditions(){
            return build(conditions);
    }

    public AppsV1beta1DeploymentCondition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public AppsV1beta1DeploymentCondition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public AppsV1beta1DeploymentCondition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public AppsV1beta1DeploymentCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentConditionBuilder> predicate){
            for (AppsV1beta1DeploymentConditionBuilder item: conditions) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentConditionBuilder> predicate){
            for (AppsV1beta1DeploymentConditionBuilder item: conditions) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withConditions(List<AppsV1beta1DeploymentCondition> conditions){
            if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<AppsV1beta1DeploymentConditionBuilder>(); for (AppsV1beta1DeploymentCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
    }

    public A withConditions(AppsV1beta1DeploymentCondition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (AppsV1beta1DeploymentCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> addNewConditionLike(AppsV1beta1DeploymentCondition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> setNewConditionLike(int index,AppsV1beta1DeploymentCondition item){
            return new ConditionsNestedImpl(index, item);
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public AppsV1beta1DeploymentStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    public Integer getReadyReplicas(){
            return this.readyReplicas;
    }

    public A withReadyReplicas(Integer readyReplicas){
            this.readyReplicas=readyReplicas; return (A) this;
    }

    public Boolean hasReadyReplicas(){
            return this.readyReplicas != null;
    }

    public Integer getReplicas(){
            return this.replicas;
    }

    public A withReplicas(Integer replicas){
            this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas(){
            return this.replicas != null;
    }

    public Integer getUnavailableReplicas(){
            return this.unavailableReplicas;
    }

    public A withUnavailableReplicas(Integer unavailableReplicas){
            this.unavailableReplicas=unavailableReplicas; return (A) this;
    }

    public Boolean hasUnavailableReplicas(){
            return this.unavailableReplicas != null;
    }

    public Integer getUpdatedReplicas(){
            return this.updatedReplicas;
    }

    public A withUpdatedReplicas(Integer updatedReplicas){
            this.updatedReplicas=updatedReplicas; return (A) this;
    }

    public Boolean hasUpdatedReplicas(){
            return this.updatedReplicas != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AppsV1beta1DeploymentStatusFluentImpl that = (AppsV1beta1DeploymentStatusFluentImpl) o;
            if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
            if (collisionCount != null ? !collisionCount.equals(that.collisionCount) :that.collisionCount != null) return false;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (readyReplicas != null ? !readyReplicas.equals(that.readyReplicas) :that.readyReplicas != null) return false;
            if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
            if (unavailableReplicas != null ? !unavailableReplicas.equals(that.unavailableReplicas) :that.unavailableReplicas != null) return false;
            if (updatedReplicas != null ? !updatedReplicas.equals(that.updatedReplicas) :that.updatedReplicas != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends AppsV1beta1DeploymentConditionFluentImpl<AppsV1beta1DeploymentStatusFluent.ConditionsNested<N>> implements AppsV1beta1DeploymentStatusFluent.ConditionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final AppsV1beta1DeploymentConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,AppsV1beta1DeploymentCondition item){
                    this.index = index;
                    this.builder = new AppsV1beta1DeploymentConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new AppsV1beta1DeploymentConditionBuilder(this);
            }
    
    public N and(){
            return (N) AppsV1beta1DeploymentStatusFluentImpl.this.setToConditions(index, builder.build());
    }
    public N endCondition(){
            return and();
    }

}


}
